@@ -55,12 +55,12 @@ class KLineEditPrivate;
  * modes on the fly based on their preference.
  *
  * To support these new features KLineEdit also emits a few more
- * additional signals.  These are: completion( const QString& ),
+ * additional signals. These are: completion( const QString& ),
  * textRotation( KeyBindingType ), and returnPressed( const QString& ).
  * The completion signal can be connected to a slot that will assist the
- * user in filling out the remaining text.  The text rotation signal is
+ * user in filling out the remaining text. The text rotation signal is
  * intended to be used to iterate through the list of all possible matches
- * whenever there is more than one match for the entered text.  The
+ * whenever there is more than one match for the entered text. The
  * @p returnPressed( const QString& ) signals are the same as QLineEdit's
  * except it provides the current text in the widget as its argument whenever
  * appropriate.
@@ -68,15 +68,15 @@ class KLineEditPrivate;
  * This widget by default creates a completion object when you invoke
  * the completionObject( bool ) member function for the first time or
  * use setCompletionObject( KCompletion*, bool ) to assign your own
- * completion object.  Additionally, to make this widget more functional,
+ * completion object. Additionally, to make this widget more functional,
  * KLineEdit will by default handle the text rotation and completion
  * events internally when a completion object is created through either one
- * of the methods mentioned above.  If you do not need this functionality,
+ * of the methods mentioned above. If you do not need this functionality,
  * simply use KCompletionBase::setHandleSignals( bool ) or set the
  * boolean parameter in the above functions to false.
  *
  * The default key-bindings for completion and rotation is determined
- * from the global settings in KStandardShortcut.  These values, however,
+ * from the global settings in KStandardShortcut. These values, however,
  * can be overridden locally by invoking KCompletionBase::setKeyBinding().
  * The values can easily be reverted back to the default setting, by simply
  * calling useGlobalSettings(). An alternate method would be to default
@@ -95,7 +95,7 @@ class KLineEditPrivate;
  * and is done to give visual distinction between the three different modes:
  * disabled, read-only, and read-write.
  *
- * KLineEdit has also a password mode which depends of globals KDE settings.  Use
+ * KLineEdit has also a password mode which depends of globals KDE settings. Use
  * KLineEdit::setPasswordMode instead of QLineEdit::echoMode property to have a password field.
  *
  * \b Usage \n
@@ -155,15 +155,15 @@ class KCOMPLETION_EXPORT KLineEdit : public QLineEdit, public KCompletionBase //
 
     Q_OBJECT
     Q_DECLARE_PRIVATE(KLineEdit)
-#ifndef KDE_NO_DEPRECATED
+#ifndef KCOMPLETION_NO_DEPRECATED
     Q_PROPERTY(bool contextMenuEnabled READ isContextMenuEnabled WRITE setContextMenuEnabled)
 #endif
-#ifndef KDE_NO_DEPRECATED
+#ifndef KCOMPLETION_NO_DEPRECATED
     Q_PROPERTY(bool urlDropsEnabled READ urlDropsEnabled WRITE setUrlDropsEnabled)
 #endif
     Q_PROPERTY(bool trapEnterKeyEvent READ trapReturnKey WRITE setTrapReturnKey)
     Q_PROPERTY(bool squeezedTextEnabled READ isSqueezedTextEnabled WRITE setSqueezedTextEnabled)
-#ifndef KDE_NO_DEPRECATED
+#ifndef KCOMPLETION_NO_DEPRECATED
     Q_PROPERTY(QString clickMessage READ clickMessage WRITE setClickMessage)
 #endif
     Q_PROPERTY(bool showClearButton READ isClearButtonShown WRITE setClearButtonShown)
@@ -178,13 +178,13 @@ public:
      * @param string Text to be shown in the edit widget.
      * @param parent The parent widget of the line edit.
      */
-    explicit KLineEdit(const QString &string, QWidget *parent = 0);
+    explicit KLineEdit(const QString &string, QWidget *parent = nullptr);
 
     /**
      * Constructs a line edit
      * @param parent The parent widget of the line edit.
      */
-    explicit KLineEdit(QWidget *parent = 0);
+    explicit KLineEdit(QWidget *parent = nullptr);
 
     /**
      *  Destructor.
@@ -198,14 +198,14 @@ public:
     void setUrl(const QUrl &url);
 
     /**
-    * Re-implemented from KCompletionBase for internal reasons.
+    * Reimplemented from KCompletionBase for internal reasons.
     *
     * This function is re-implemented in order to make sure that
     * the EchoMode is acceptable before we set the completion mode.
     *
     * See KCompletionBase::setCompletionMode
     */
-    virtual void setCompletionMode(KCompletion::CompletionMode mode);
+    void setCompletionMode(KCompletion::CompletionMode mode) Q_DECL_OVERRIDE;
 
     /**
      * Disables completion modes by makeing them non-checkable.
@@ -227,17 +227,17 @@ public:
      * menu.
      *
      * @param showMenu If @p true, show the context menu.
-     * @deprecated use setContextMenuPolicy
+     * @deprecated since 4.5, use setContextMenuPolicy instead
      */
-#ifndef KDE_NO_DEPRECATED
+#ifndef KCOMPLETION_NO_DEPRECATED
     virtual KCOMPLETION_DEPRECATED void setContextMenuEnabled(bool showMenu);
 #endif
 
     /**
      * Returns @p true when the context menu is enabled.
-     * @deprecated use contextMenuPolicy
+     * @deprecated since 4.5, use contextMenuPolicy instead
      */
-#ifndef KDE_NO_DEPRECATED
+#ifndef KCOMPLETION_NO_DEPRECATED
     KCOMPLETION_DEPRECATED bool isContextMenuEnabled() const;
 #endif
 
@@ -245,13 +245,11 @@ public:
      * Enables/Disables handling of URL drops. If enabled and the user
      * drops an URL, the decoded URL will be inserted. Otherwise the default
      * behavior of QLineEdit is used, which inserts the encoded URL.
+     * Call setUrlDropsEnabled(false) if you need dropEvent to be called in a KLineEdit subclass.
      *
      * @param enable If @p true, insert decoded URLs
-     * @deprecated since 5.0. Use installEventFilter with a LineEditUrlDropEventFilter
      */
-#ifndef KDE_NO_DEPRECATED
-    KCOMPLETION_DEPRECATED void setUrlDropsEnabled(bool enable);
-#endif
+    void setUrlDropsEnabled(bool enable);  // KF6: remove it and don't create LineEditUrlDropEventFilter by default.
 
     /**
      * Returns @p true when decoded URL drops are enabled
@@ -286,12 +284,12 @@ public:
      * @param create Set this to false if you don't want the box to be created
      *               i.e. to test if it is available.
      */
-    KCompletionBox *completionBox(bool create = true);    // KDE5 TODO: make virtual, so konq can reimplement i
+    virtual KCompletionBox *completionBox(bool create = true);
 
     /**
      * Reimplemented for internal reasons, the API is not affected.
      */
-    virtual void setCompletionObject(KCompletion *, bool hsig = true);
+    void setCompletionObject(KCompletion *, bool handle = true) Q_DECL_OVERRIDE;
 
     /**
      * Reimplemented for internal reasons, the API is not affected.
@@ -346,17 +344,17 @@ public:
      * This makes the line edit display a grayed-out hinting text as long as
      * the user didn't enter any text. It is often used as indication about
      * the purpose of the line edit.
-     * @deprecated Use QLineEdit::setPlaceholderText instead.
+     * @deprecated since 5.0, use QLineEdit::setPlaceholderText instead.
      */
-#ifndef KDE_NO_DEPRECATED
+#ifndef KCOMPLETION_NO_DEPRECATED
     KCOMPLETION_DEPRECATED void setClickMessage(const QString &msg);
 #endif
 
     /**
      * @return the message set with setClickMessage
-     * @deprecated Use QLineEdit::placeholderText instead.
+     * @deprecated since 5.0, use QLineEdit::placeholderText instead.
      */
-#ifndef KDE_NO_DEPRECATED
+#ifndef KCOMPLETION_NO_DEPRECATED
     KCOMPLETION_DEPRECATED QString clickMessage() const;
 #endif
 
@@ -374,7 +372,7 @@ public:
 
     /**
      * @return the size used by the clear button
-     * @since KDE 4.1
+     * @since 4.1
      **/
     QSize clearButtonUsedSize() const;
 
@@ -385,7 +383,7 @@ public:
      *
      * @since 4.2.1
      */
-    void doCompletion(const QString &txt);
+    void doCompletion(const QString &text);
 
 Q_SIGNALS:
 
@@ -397,7 +395,7 @@ Q_SIGNALS:
     /**
      * Emitted when the user presses the return key.
      *
-     *  The argument is the current text.  Note that this
+     *  The argument is the current text. Note that this
      * signal is @em not emitted if the widget's @p EchoMode is set to
      * QLineEdit::EchoMode.
      */
@@ -429,7 +427,7 @@ Q_SIGNALS:
      * (by typing or accepting autocompletion), without side effects from
      * suggested autocompletion either. userTextChanged isn't needed anymore.
      */
-#ifndef KDE_NO_DEPRECATED
+#ifndef KCOMPLETION_NO_DEPRECATED
     QT_MOC_COMPAT void userTextChanged(const QString &);
 #endif
 
@@ -462,9 +460,9 @@ Q_SIGNALS:
      * provided through since it is created and deleted
      * on demand.
      *
-     * @param p the context menu about to be displayed
+     * @param contextMenu the context menu about to be displayed
      */
-    void aboutToShowContextMenu(QMenu *menu);
+    void aboutToShowContextMenu(QMenu *contextMenu);
 
     /**
      * Emitted when the user clicked on the clear button
@@ -494,7 +492,7 @@ public Q_SLOTS:
     /**
      * See KCompletionBase::setCompletedText.
      */
-    virtual void setCompletedText(const QString &);
+    void setCompletedText(const QString &) Q_DECL_OVERRIDE;
 
     /**
      * Same as the above function except it allows you to temporarily
@@ -504,13 +502,7 @@ public Q_SLOTS:
      * @param items list of completion matches to be shown in the completion box.
      * @param autoSuggest true if you want automatic text completion (suggestion) enabled.
      */
-    void setCompletedItems(const QStringList &items, bool autoSuggest = true);
-
-    /**
-     * Reimplemented to workaround a buggy QLineEdit::clear()
-     * (changing the clipboard to the text we just had in the lineedit)
-     */
-    virtual void clear(); // ### KDE 5: check if still required
+    void setCompletedItems(const QStringList &items, bool autoSuggest = true) Q_DECL_OVERRIDE;
 
     /**
      * Squeezes @p text into the line edit.
@@ -519,16 +511,16 @@ public Q_SLOTS:
     void setSqueezedText(const QString &text);
 
     /**
-     * Re-implemented to enable text squeezing. API is not affected.
+     * Reimplemented to enable text squeezing. API is not affected.
      */
     virtual void setText(const QString &);
 
     /**
      * @brief set the line edit in password mode.
      * this change the EchoMode according to KDE preferences.
-     * @param b true to set in password mode
+     * @param passwordMode true to set in password mode
      */
-    void setPasswordMode(bool b = true);
+    void setPasswordMode(bool passwordMode = true);
 
     /**
      * @return returns true if the lineedit is set to password mode echoing
@@ -553,54 +545,54 @@ protected Q_SLOTS:
 protected:
 
     /**
-     * Re-implemented for internal reasons.  API not affected.
+     * Reimplemented for internal reasons. API not affected.
      */
-    virtual bool event(QEvent *);
+    bool event(QEvent *) Q_DECL_OVERRIDE;
 
     /**
-    * Re-implemented for internal reasons.  API not affected.
+    * Reimplemented for internal reasons. API not affected.
     *
     * See QLineEdit::resizeEvent().
     */
-    virtual void resizeEvent(QResizeEvent *);
+    void resizeEvent(QResizeEvent *) Q_DECL_OVERRIDE;
 
     /**
-    * Re-implemented for internal reasons.  API not affected.
+    * Reimplemented for internal reasons. API not affected.
     *
     * See QLineEdit::keyPressEvent().
     */
-    virtual void keyPressEvent(QKeyEvent *);
+    void keyPressEvent(QKeyEvent *) Q_DECL_OVERRIDE;
 
     /**
-    * Re-implemented for internal reasons.  API not affected.
+    * Reimplemented for internal reasons. API not affected.
     *
     * See QLineEdit::mousePressEvent().
     */
-    virtual void mousePressEvent(QMouseEvent *);
+    void mousePressEvent(QMouseEvent *) Q_DECL_OVERRIDE;
 
     /**
-    * Re-implemented for internal reasons.  API not affected.
+    * Reimplemented for internal reasons. API not affected.
     *
     * See QLineEdit::mouseReleaseEvent().
     */
-    virtual void mouseReleaseEvent(QMouseEvent *);
+    void mouseReleaseEvent(QMouseEvent *) Q_DECL_OVERRIDE;
 
     /**
-    * Re-implemented for internal reasons.  API not affected.
+    * Reimplemented for internal reasons. API not affected.
     *
     * See QWidget::mouseDoubleClickEvent().
     */
-    virtual void mouseDoubleClickEvent(QMouseEvent *);
+    void mouseDoubleClickEvent(QMouseEvent *) Q_DECL_OVERRIDE;
 
     /**
-    * Re-implemented for internal reasons.  API not affected.
+    * Reimplemented for internal reasons. API not affected.
     *
     * See QLineEdit::contextMenuEvent().
     */
-    virtual void contextMenuEvent(QContextMenuEvent *);
+    void contextMenuEvent(QContextMenuEvent *) Q_DECL_OVERRIDE;
 
     /**
-    * Re-implemented for internal reasons.  API not affected.
+    * Reimplemented for internal reasons. API not affected.
     *
     * See QLineEdit::createStandardContextMenu().
     */
@@ -627,17 +619,17 @@ protected:
     */
     bool autoSuggest() const;
 
-    virtual void paintEvent(QPaintEvent *ev);
+    void paintEvent(QPaintEvent *ev) Q_DECL_OVERRIDE;
 
 private:
     const QScopedPointer<KLineEditPrivate> d_ptr;
 
     Q_PRIVATE_SLOT(d_func(), void _k_textChanged(const QString &))
-    Q_PRIVATE_SLOT(d_func(), void completionMenuActivated(QAction *))
-    Q_PRIVATE_SLOT(d_func(), void tripleClickTimeout())
-    Q_PRIVATE_SLOT(d_func(), void slotRestoreSelectionColors())
-    Q_PRIVATE_SLOT(d_func(), void _k_slotCompletionBoxTextChanged(const QString &))
-    Q_PRIVATE_SLOT(d_func(), void updateClearButtonIcon(const QString &))
+    Q_PRIVATE_SLOT(d_func(), void _k_completionMenuActivated(QAction *))
+    Q_PRIVATE_SLOT(d_func(), void _k_tripleClickTimeout())
+    Q_PRIVATE_SLOT(d_func(), void _k_restoreSelectionColors())
+    Q_PRIVATE_SLOT(d_func(), void _k_completionBoxTextChanged(const QString &))
+    Q_PRIVATE_SLOT(d_func(), void _k_updateClearButtonIcon(const QString &))
 };
 
 #endif
